@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2022-07-14 17:12:09
+@LastEditTime: 2022-07-25 18:43:26
 @LastEditors: HuangJianYi
 :description: App相关
 """
@@ -105,6 +105,9 @@ class BaseInfoHandler(SevenBaseHandler):
         default_box_style["title"] = "默认模板"
         default_box_style["pic_url"] = "https://isv.alibabausercontent.com/00000000/imgextra/i3/2206353354303/O1CN016E9TQD1heotGpXFkW_!!2206353354303-2-isvtu-00000000.png"
 
+        helper_info = {}
+        helper_info["phone"] = ""
+
         data = {}
         data["serverName"] = "在线拆盲盒模板"
         data["info"] = info
@@ -112,6 +115,13 @@ class BaseInfoHandler(SevenBaseHandler):
         data["bottom_button"] = bottom_button_list
         data["use_point"] = use_point_list
         data["default_box_style"] = default_box_style
+        store_user_nick = self.get_taobao_param().user_nick.split(':')[0]
+        if store_user_nick:
+            app_info_model = AppInfoModel(context=self)
+            app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
+            if app_info:
+                helper_info["phone"] = app_info.app_telephone
+        data["helper_info"] = helper_info
         if base_info:
             # 把string转成数组对象
             base_info.update_function = self.json_loads(base_info.update_function) if base_info.update_function else []
@@ -126,7 +136,9 @@ class BaseInfoHandler(SevenBaseHandler):
                 if user_nick == config.get_value("test_user_nick"):
                     base_info.client_ver = config.get_value("test_client_ver")
                     base_info.update_function = []
-            data["base_info"] = base_info.__dict__
+            base_info_dict = base_info.__dict__
+            base_info_dict["is_force_phone"] = config.get_value("is_force_phone",True)
+            data["base_info"] = base_info_dict
 
         if base_info:
             return self.reponse_json_success(data)
